/**
 * Lorsque l'objet dont l'identifiant est 'graphml' (il s'agit de l'objet xml) est chargé et prèt à être utilisé, on crée le convertisseur XML 2 JSON.
 * On en profite pour créer les éléments JSON qui seront ensuite utilisé par Graph.
 */
$("#graphml").ready(function () {
    /* Take data from request. */
    myClass = $("#request_Class").text();
    myKey = $("#request_Key").text();
    myValue = $("#request_Value").text();
    myFilter = $("#request_Filter").text().split("|");
    myCauseDepth = $("#request_CauseDepth").text();
    myImpactDepth = $("#request_ImpactDepth").text();
    myImpactLevel = $("#request_ImpactLevel").text();
    myCypher = $("#request_Cypher").text();
    myLimit = $("#request_Limit").text();

    convertXMLToJSON = new ConvertXmlToJson($("#graphml").find('*').filter(function() {
        var regEx = /graph$/;
        return this.nodeName.toLowerCase().match(regEx) !== null ;
    }));

    var json = convertXMLToJSON.getJSON();

    isGraphmlOk = json.length > 0;

    /*
     * Si le graph est valide, on crée instancie tous les objets du graph.
     */
    if (isGraphmlOk) {
        elementJSON = new ElementJSON(json);

        $("#home").ready(function () {
            $("#home").click(function () {
                window.location.href = racineUrl+"lavoisier/"+pageName;
            });
        });
        /**
         * Initialise le qTip pour les settings du graphe.
         */
        $("#parameters").ready(function () {
            initQtipButton();
        });

        /**
         * Mise en place de l'évènement change sur le select.
         * Dès qu'il change et en fonction du layout sélectionné, il faut afficher la section layout group.
         */
        $("#layout-select").ready(function () {
            //Modification des informations donnée par la propriété valeur des options pour obtenir une valeur sous forme de tableau.
            $("#layout-select > option").each(function () {
                // Modification du contenu de l'option pour affichage "colonne"
                var content = $(this).html();
                var layout_name = content.substring(0, content.search(/\d/));
                var layout_rapidity = content.substring(content.indexOf("|"));
                var nbSpaces = content.substring(content.search(/\d/), content.indexOf("|"));
                var spaces = "";
                for (var i = 1 ; i <= parseInt(nbSpaces) ; i++) {
                    spaces += "&nbsp;";
                }
                $(this).html(layout_name + spaces + layout_rapidity);

                // Modification valeur de l'option pour correspondre à < {type:"", nom:""} >
                var valeur = $(this).val();
                var type = valeur.substring(0, valeur.indexOf("_"));
                var nom = valeur.substring(valeur.indexOf("_") + 1);

                $(this).val('{"type":"' + type + '","nom":"' + nom + '"}');
            });
            //Attribution de l'évènement 'change' du select.
            $("#layout-select").change(function () { afficheCacheLayoutGroup($(this).val()); });
        });
        /**
         * Gestion de l'activation du filtrage.
         */
        $(document.querySelectorAll("input[name=\"activate_deactivate_classesfilter\"]")).ready(function () {
            $(document.querySelectorAll("input[name=\"activate_deactivate_classesfilter\"]")).change(function () {
                if ($(document.querySelectorAll("input[name=\"activate_deactivate_classesfilter\"]:checked")).val() === "on") {
                    $("#filters_classes h4 span").text("(enabled)");    // Informe l'utilisateur que le filtrage est activé.
                    $("#classes_div").fadeIn(150);                                    // Affiche les classes de filtrage.
                } else {
                    $("#filters_classes h4 span").text("(disabled)");   // Informe l'utilisateur que le filtrage est désactivé.
                    $("#classes_div").fadeOut(150);                                   // Cache les classes de filtrage.
                }
            });
        });
        /**
         * Création de l'UI des filtres.
         */
        $("#filters_classes").ready(function () {
            createFiltersClasses();
        });
        /**
         * Ajout du click sur le bouton d'export.
         */
        $("#exportAsXML").ready(function () {
            $("#exportAsXML").click(function () {
                open("view-source:" + document.URL, "_blank");
            });
        });

        /**
         * Charge la fonction permettant d'imprimer la page d'aide.
         */
        $("#print_help").ready(function () {
            printHelp();
        });

        if (!myCypher) {
            /**
             * Opacifie la div depth lorsque l'utilisateur passe la souris dessus.
             */
            $("#depth").ready(function () {
                $("#depth").removeClass("hidden");

                $("#depth").hover(function () {
                    this.style.opacity = 1;
                }, function () {
                    this.style.opacity = 0.5;
                });
            });
            /**
             * Création du slide vertical de la "profondeur des causes" du graph.
             * Implique un rechargement de la page.
             */
            $("#slider-vertical-cause").ready(function () {
                $("#slider-vertical-cause").slider({
                    orientation: "vertical",
                    range: "min",
                    min: 0,
                    max: 10,
                    value: myCauseDepth,
                    slide: function (event, ui) {
                        $("#causeDepthLevel").val(ui.value);
                        if (ui.value > 3) {
                            if (!$("#slider-vertical-cause > div").hasClass("red")) $("#slider-vertical-cause > div").addClass("red");
                        } else {
                            if ($("#slider-vertical-cause > div").hasClass("red")) $("#slider-vertical-cause > div").removeClass("red");
                        }
                    },
                    stop: function (event, ui) {
                        reloadWithDepth(ui.value);
                    }
                });
                $("#causeDepthLevel").val($("#slider-vertical-cause").slider("value"));
            });
            /**
             * Création du slide vertical de la "profondeur des impacts" du graph.
             * Implique un rechargement de la page.
             */
            $("#slider-vertical-impact").ready(function () {
                $("#slider-vertical-impact").slider({
                    orientation: "vertical",
                    range: "min",
                    min: 0,
                    max: 10,
                    value: myImpactDepth,
                    slide: function (event, ui) {
                        $("#impactDepthLevel").val(ui.value);
                        if (ui.value > 7) {
                            if (!$("#slider-vertical-impact > div").hasClass("red")) $("#slider-vertical-impact > div").addClass("red");
                        } else {
                            if ($("#slider-vertical-impact > div").hasClass("red")) $("#slider-vertical-impact > div").removeClass("red");
                        }
                    },
                    stop: function (event, ui) {
                        reloadWithDepth(undefined, ui.value);
                    }
                });
                $("#impactDepthLevel").val($("#slider-vertical-impact").slider("value"));
            });
            /**
             * Ajout du click de remise par défaut des profondeurs du graph.
             */
            $("#default-depth").ready(function () {
                $("#default-depth").click(function () { reloadWithDepth(); });
            });
        }
    
        /**
         * Ajout du click sur le bouton d'aide pour ouvrir la JDialog d'aide.
         */
        $("#help").ready(function () {
            createHelpDialog();
            $("#help_main_screen > section, #help_graph > section, #help_settings > section").show();
            $("#help_main_screen > section, #help_graph > section, #help_settings > section").hide();
    
            $("#help_main_screen > header").click(function () {
                if ($("#help_main_screen > section").is(":visible")) {
                    $("#help_main_screen > section").fadeOut(150);
                    $(this).find("h2").removeClass("open");
                } else {
                    $("#help_main_screen > section").fadeIn(150);
                    $(this).find("h2").addClass("open");
                }
            });
    
            $("#help_graph > header").click(function () {
                if ($("#help_graph > section").is(":visible")) {
                    $("#help_graph > section").fadeOut(150);
                    $(this).find("h2").removeClass("open");
                } else {
                    $("#help_graph > section").fadeIn(150);
                    $(this).find("h2").addClass("open");
                }
            });
    
            $("#help_settings > header").click(function () {
                if ($("#help_settings > section").is(":visible")) {
                    $("#help_settings > section").fadeOut(150);
                    $(this).find("h2").removeClass("open");
                } else {
                    $("#help_settings > section").fadeIn(150);
                    $(this).find("h2").addClass("open");
                }
            });
    
            $("#help").click(function () {
                if (!$("#help_dialog").dialog("isOpen")) {
                    $("#help_dialog").dialog("open");
                }
            });
        });

        /**
         * Initialisation du graph lorsque la page est entièrement chargé.
         */
        $(document).ready(function () {

            graph = new Graph(elementJSON);

            /* GET ALL VALUES FROM STORAGE */
            if (typeof(Storage) !== "undefined") {
                /* LAYOUT */
                /* Layout */
                if (sessionStorage.getItem("layout")) $("#layout-select").val(sessionStorage.getItem("layout"));
                else
                    $('#layout-select').val('{"type":"viz","nom":"dot"}');
                /* Layout_group */
                if (sessionStorage.getItem("layout_group")) input_pre_check("group", sessionStorage.getItem("layout_group"));
                /* Collapse_group */
                if (sessionStorage.getItem("collapse_group")) input_pre_check("collapse_group", sessionStorage.getItem("collapse_group"));
                /* FILTRE */
                /* Filtre_status */
                if (sessionStorage.getItem("filtre_status")) input_pre_check("activate_deactivate_classesfilter", sessionStorage.getItem("filtre_status"));
                /* FIT|CENTER */
                /* Fit_center */
                if (sessionStorage.getItem("fit_center")) input_pre_check("fitorcenterchoice", sessionStorage.getItem("fit_center"));
                /* Element_to */
                if (sessionStorage.getItem("element_to")) input_pre_check("fitorcenterto", sessionStorage.getItem("element_to"));
            }
            /* Graphe_filtre */
            for (var i = 0 ; i < myFilter.length ; i++) {
                $("#input" + myFilter[i]).prop("checked", false);
            }
            /* Si la class demandé lors de la requête correspond à un élément préfiltré, on enlève cette class du filtrage. */
            if (myFilter.indexOf(myClass) !== -1) $("#input" + myClass).prop("checked", true);
            /* Utilisation de l'évènement pour activation du filtre. */
            if (typeof(Storage) === "undefined" || !sessionStorage.getItem("filtre_status")) $("#activate_classesfilter").prop("checked", true);

            if (graph.getCy().nodes().size() > 200) {
                if (!((typeof(Storage) !== "undefined") && sessionStorage.getItem("layout"))) $("#layout-select").val('{"type":"cyto","nom":"grid"}');
            }

            /* Lancement des évènements pour prise en charge des paramètres par défaut. */
            $("#layout-select").change();
            $("input[name='collapse_group']").change();
            $("input[name=\"activate_deactivate_classesfilter\"]").change();
            $("#fit_or_center_apply_button").click();
            /* Application des réglages par défauts. */
            $("#graphe_action__button").click();
        });
    } else {
        /*
         * Empty graph.
         */
        $("graph").addClass("hide");
        $(".no-graph").removeClass("hide");
    }
});